@@ -1,5 +1,4 @@
-from .add import add_auth
-from .routing import (
+from svc_infra.api.fastapi.dual.protected import (
     optional_principal_router,
     protected_router,
     roles_router,
@@ -7,6 +6,8 @@ from .routing import (
     user_router,
 )
 
+from .add import add_auth
+
 __all__ = [
     "add_auth",
     "optional_principal_router",
