@@ -3,19 +3,19 @@ from __future__ import annotations
 from datetime import datetime, timedelta, timezone
 from typing import List, Optional
 
-from fastapi import APIRouter, Depends, HTTPException
+from fastapi import Depends, HTTPException
 from pydantic import BaseModel, Field
 from sqlalchemy import select
 
-from svc_infra.api.fastapi.auth.routing import user_router
 from svc_infra.api.fastapi.auth.security import current_principal
 from svc_infra.api.fastapi.db.sql.session import SqlSessionDep
+from svc_infra.api.fastapi.dual.protected import user_router
 from svc_infra.db.sql.apikey import get_apikey_model
 
 
 class ApiKeyCreateIn(BaseModel):
     name: str
-    user_id: Optional[str] = None  # if omitted => bound to caller or service key if caller is None
+    user_id: Optional[str] = None
     scopes: List[str] = Field(default_factory=list)
     ttl_hours: Optional[int] = 24 * 365  # default 1y
 
@@ -32,7 +32,7 @@ class ApiKeyOut(BaseModel):
     last_used_at: Optional[datetime]
 
 
-def apikey_router(prefix: str = "/auth/keys") -> APIRouter:
+def apikey_router(prefix: str = "/auth/keys"):
     r = user_router(prefix=prefix, tags=["auth:apikeys"])
     ApiKey = get_apikey_model()
 
@@ -40,7 +40,6 @@ def apikey_router(prefix: str = "/auth/keys") -> APIRouter:
     async def create_key(
         sess: SqlSessionDep, payload: ApiKeyCreateIn, p=Depends(current_principal)
     ):
-        # p.user is guaranteed
         owner_id = payload.user_id or getattr(p.user, "id", None)
         if owner_id != getattr(p.user, "id") and not getattr(p.user, "is_superuser", False):
             raise HTTPException(403, "forbidden")
@@ -65,7 +64,7 @@ def apikey_router(prefix: str = "/auth/keys") -> APIRouter:
             id=str(row.id),
             name=row.name,
             user_id=str(row.user_id) if row.user_id else None,
-            key=plaintext,
+            key=plaintext,  # show once
             key_prefix=row.key_prefix,
             scopes=row.scopes,
             active=row.active,
